dmeasure evaluates the probability density of a set of measurements given the state of the system.
This function is part of the low-level interface to pomp objects.
This help page does not give instructions on the implementation of models: see pomp for instructions.dmeasure(object, y, x, times, params, log = FALSE, ...)
## S3 method for class 'pomp':
dmeasure(object, y, x, times, params, log = FALSE, \dots)nreps x ntimes.
If d is the returned matrix, d[j,k] is the likelihood of the observation y[,k] at time times[k] given the state x[,j,k].dmeasure slot of the pomp object.
For specifications on writing such a function, see pomp.pomp-class, pomp