rmeasure-pomp: Simulate the measurement model of a partially-observed Markov process
Description
The method rmeasure draws from the distribution of measurements given the state of the system.
This function is part of the low-level interface to pomp objects.
This help page does not give instructions on the implementation of models: see pomp for instructions.Usage
## S3 method for class 'pomp':
rmeasure(object, x, times, params, \dots)
Value
- Returns a rank-3 array of dimensions
nobs x nreps x ntimes, where nobs is the number of observed variables.
Details
This function is essentially a wrapper around the user-supplied rmeasure slot of the pomp object.
For specifications on writing such a function, see pomp.